/*  
 * Copyright (c) 2011 Ant Kutschera
 * 
 * This file is part of Ant Kutschera's blog, 
 * http://blog.maxant.co.uk
 * 
 * This is free software: you can redistribute
 * it and/or modify it under the terms of the
 * Lesser GNU General Public License as published by
 * the Free Software Foundation, either version 3 of
 * the License, or (at your option) any later version.
 * 
 * It is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied
 * warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR
 * PURPOSE.  See the Lesser GNU General Public License for
 * more details. 
 * 
 * You should have received a copy of the
 * Lesser GNU General Public License along with this software.
 * If not, see http://www.gnu.org/licenses/.
 */
package ch.maxant.blog.nio.voipapplication.client;

import java.io.IOException;
import java.io.InputStream;
import java.net.Socket;

import ch.maxant.blog.nio.voipapplication.common.Packet;
import ch.maxant.blog.nio.voipapplication.common.VoipProtocol;

public class VoipClientProtocol extends VoipProtocol {

	private Socket socket;
	
	public VoipClientProtocol(Socket s) {
		socket = s;
	}
	
	/**
	 * sends a login command sync.  the response (the session ID) is read and returned.
	 * @param name the login or friendly name of this client.
	 */
	public String login(String name) throws IOException {
		byte[] data = new Packet(name.getBytes(CHARSET), LOGIN).marshal();
		socket.getOutputStream().write(data);
		socket.getOutputStream().flush();

		//read login response
		Packet resp = readPacket();
		
		if(resp.getCommand() != LOGIN){
			throw new IOException("Failed to login.  Response wsa: " + resp.getPayloadAsString());
		}
		return resp.getPayloadAsString(); //the session id
	}

	/** sends a time request command async.  the response needs to be handled elsewhere. */
	public void getServerTime() throws IOException {
		byte[] data = new Packet(TIME).marshal();
		socket.getOutputStream().write(data);
		socket.getOutputStream().flush();
		
		//should be handled elsewhere - this is an async method
	}
	
	/** sends a hangup command async.  the response needs to be handled elsewhere. */
	public void hangup() throws IOException {
		byte[] data = new Packet(END_CALL).marshal();
		socket.getOutputStream().write(data);
		socket.getOutputStream().flush();
	}

	/** initiate a call to "who", async.  the response needs to be handled elsewhere. */
	public void call(final String who) throws IOException {
		byte[] data = new Packet(who.getBytes(CHARSET), START_CALL).marshal();
		socket.getOutputStream().write(data);
		socket.getOutputStream().flush();
	}

	/** sends a packet of call data async.  the response needs to be handled elsewhere. */
	public void sendCallData(byte[] data) throws IOException {
		byte[] packet = new Packet(data, CALL_DATA).marshal();
		socket.getOutputStream().write(packet);
		socket.getOutputStream().flush();
	}

	/** sends a quit command async.  the response needs to be handled elsewhere. */
	public void quit() throws IOException {
		byte[] packet = new Packet(QUIT).marshal();
		socket.getOutputStream().write(packet);
		socket.getOutputStream().flush();
	}
	
	/** reads a packet off the input stream of the socket. */
	public Packet readPacket() throws IOException {
		InputStream is = socket.getInputStream();
		byte command = (byte) is.read();
		int length = is.read();
		byte[] payload = new byte[length];
		is.read(payload, 0, length);
		return new Packet(payload, command);
	}
	
}
