/*  
 * Copyright (c) 2011 Ant Kutschera
 * 
 * This file is part of Ant Kutschera's blog, 
 * http://blog.maxant.co.uk
 * 
 * This is free software: you can redistribute
 * it and/or modify it under the terms of the
 * Lesser GNU General Public License as published by
 * the Free Software Foundation, either version 3 of
 * the License, or (at your option) any later version.
 * 
 * It is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied
 * warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR
 * PURPOSE.  See the Lesser GNU General Public License for
 * more details. 
 * 
 * You should have received a copy of the
 * Lesser GNU General Public License along with this software.
 * If not, see http://www.gnu.org/licenses/.
 */
package ch.maxant.blog.nio.voipapplication.common;


/**
 * @see VoipProtocol
 */
public class Packet {
	
	/** payload in a packet may not be larger than this */
	public static final int MAX_PAYLOAD_SIZE = (2 << 8)-1; //ie what we can measure using one byte :-)

	byte command;
	byte[] payload;

	/**
	 * unmarshals the packet into this object
	 * @param packet format is as defined in protocol
	 * @see VoipProtocol
	 */
	public Packet(byte[] packet){
		this.command = packet[0];
		int length = packet[1];
		if(length < 0) throw new RuntimeException("not yet impled - add 127 or 128 or whatever to convert.  or actually, if negative, subtract from 255?");
		this.payload = new byte[length];
		System.arraycopy(packet, 2, this.payload, 0, this.payload.length);
	}
	
	public Packet(byte[] payload, byte command){
		this.payload = payload;
		this.command = command;
	}

	public Packet(byte command){
		this.payload = new byte[0];
		this.command = command;
	}
	
	public byte getCommand(){
		return this.command;
	}
	
	public byte[] getPayload(){
		return this.payload;
	}
	
	/**
	 * @return a string created from the payload using {@link VoipProtocol#CHARSET}
	 */
	public String getPayloadAsString(){
		return new String(payload, VoipProtocol.CHARSET);
	}

	/**
	 * @return data ready to be sent across the wire.
	 */
	public byte[] marshal(){
		if(payload == null){
			payload = new byte[0];
		}
		if(payload.length > MAX_PAYLOAD_SIZE) {
			throw new IllegalArgumentException("payload more than " + MAX_PAYLOAD_SIZE + " bytes long!");
		}
		byte[] data = new byte[payload.length + 2];
		System.arraycopy(payload, 0, data, 2, payload.length);
		data[0] = command;
		data[1] = (byte) payload.length;
		return data;
	}
	
}
