/*  
 * Copyright (c) 2011 Ant Kutschera
 * 
 * This file is part of Ant Kutschera's blog, 
 * http://blog.maxant.co.uk
 * 
 * This is free software: you can redistribute
 * it and/or modify it under the terms of the
 * Lesser GNU General Public License as published by
 * the Free Software Foundation, either version 3 of
 * the License, or (at your option) any later version.
 * 
 * It is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied
 * warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR
 * PURPOSE.  See the Lesser GNU General Public License for
 * more details. 
 * 
 * You should have received a copy of the
 * Lesser GNU General Public License along with this software.
 * If not, see http://www.gnu.org/licenses/.
 */
package ch.maxant.blog.nio.voipapplication.common;

import java.nio.charset.Charset;

import ch.maxant.blog.nio.framework.ServerRequest;
import ch.maxant.blog.nio.framework.ServerResponse;
import ch.maxant.blog.nio.framework.tcp.TCPProtocol;

/**
 * command is first byte.
 * second byte is payload length, if the command contains payload
 * third and successive bytes are payload, up to 255 in number.
 */
public abstract class VoipProtocol extends TCPProtocol {

	public static final byte UNKNOWN_COMMAND = 0;
	public static final byte LOGIN = 1;
	public static final byte TIME = 2;
	public static final byte START_CALL = 3;
	public static final byte CALL_OK = 4;
	public static final byte CALL_NOK = 5;
	public static final byte CALL_DATA = 6;
	public static final byte END_CALL = 7;
	public static final byte QUIT = 8;

	private static final String CHARSET_NAME = "UTF-8";
	
	/** the default charset used in the protocol, namely {@value #CHARSET_NAME} */
	public static final Charset CHARSET = Charset.forName(CHARSET_NAME);

	/** default impl does nowt */
	public void handleRequest(ServerRequest request, ServerResponse response) {
		//we have impled this here, so that the client protocol, which is a subclass has a default impl.
		//but the server protocol needs to impl it, to be functional!
	}
	
	/** 
	 * the maximum number of bytes which will handled in a single request.
	 * actually, the protocol only allows up to {@value Byte#MAX_VALUE} 
	 * bytes, because the second byte which tells you the length is a byte!
	 */
	@Override
	public int getBufferSize() {
		return 512;

	}
}
