/*  
 * Copyright (c) 2011 Ant Kutschera
 * 
 * This file is part of Ant Kutschera's blog, 
 * http://blog.maxant.co.uk
 * 
 * This is free software: you can redistribute
 * it and/or modify it under the terms of the
 * Lesser GNU General Public License as published by
 * the Free Software Foundation, either version 3 of
 * the License, or (at your option) any later version.
 * 
 * It is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied
 * warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR
 * PURPOSE.  See the Lesser GNU General Public License for
 * more details. 
 * 
 * You should have received a copy of the
 * Lesser GNU General Public License along with this software.
 * If not, see http://www.gnu.org/licenses/.
 */
package ch.maxant.blog.nio.voipapplication.server;

import java.io.IOException;
import java.nio.channels.SelectionKey;
import java.nio.channels.SocketChannel;

import ch.maxant.blog.nio.framework.ServerRequest;
import ch.maxant.blog.nio.framework.ServerResponse;
import ch.maxant.blog.nio.framework.UnknownHandlerException;
import ch.maxant.blog.nio.voipapplication.common.Packet;
import ch.maxant.blog.nio.voipapplication.common.VoipProtocol;
import ch.maxant.blog.nio.voipapplication.server.model.VoipServerModel;

/**
 * server parts of the protocol.  
 * uses configurable handlers 
 */
public class VoipServerProtocol extends VoipProtocol {
	
	private VoipServerModel model;

	public VoipServerProtocol(){
		model = new VoipServerModel();
	}
	
	@Override
	public VoipServerModel getModel() {
		return model;
	}
	
	/**
	 * {@inheritDoc}
	 */
	@Override
	public void handleRequest(ServerRequest request, ServerResponse response) {

		String criterion = String.valueOf(request.getData()[0]);
		try{
			//call through to the context for help - it will call the handler for us.
			getContext().handleRequest(criterion , request, response);
		}catch (IOException e){
			System.err.println("failed to handle request correctly for criterion " + criterion);
			e.printStackTrace();
		} catch (UnknownHandlerException e) {
			//NOK with unknown command
			System.err.println("received unknown data.  command=" + request.getData()[0] + " and length=" + request.getData()[1]);
			try{
				response.write(new Packet(UNKNOWN_COMMAND).marshal());
			}catch (IOException e2){
				System.err.println("failed to NOK that we received an unknown command.  command=" + request.getData()[0] + " and length=" + request.getData()[1]);
				e2.printStackTrace();
			}
		}
	}

	public void closeClient(SocketChannel client, SelectionKey key) {
		
		//need to handle ending the call, so that the model finishes in a good state
		byte command = END_CALL;
		try {
			byte[] data = new Packet(command).marshal();
			getContext().handleRequest(""+command, new ServerRequest(data, key), new ServerResponse(client));
		} catch (IOException e) {
			System.err.println("failed to end call shortly before closing client connection");
			e.printStackTrace();
		} catch (UnknownHandlerException e) {
			System.err.println("failed to handle request correctly for criterion " + command);
			e.printStackTrace();
		}

		//and now physically close the connection and cancel the key
		super.closeClient(client, key);
	}

}
