/*  
 * Copyright (c) 2011 Ant Kutschera
 * 
 * This file is part of Ant Kutschera's blog, 
 * http://blog.maxant.co.uk
 * 
 * This is free software: you can redistribute
 * it and/or modify it under the terms of the
 * Lesser GNU General Public License as published by
 * the Free Software Foundation, either version 3 of
 * the License, or (at your option) any later version.
 * 
 * It is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied
 * warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR
 * PURPOSE.  See the Lesser GNU General Public License for
 * more details. 
 * 
 * You should have received a copy of the
 * Lesser GNU General Public License along with this software.
 * If not, see http://www.gnu.org/licenses/.
 */
package ch.maxant.blog.nio.voipapplication.server;

import java.io.IOException;
import java.util.HashSet;
import java.util.Set;

import ch.maxant.blog.nio.framework.Configuration;
import ch.maxant.blog.nio.framework.IHandler;
import ch.maxant.blog.nio.framework.IServerProtocol;
import ch.maxant.blog.nio.framework.ServerFactory;
import ch.maxant.blog.nio.voipapplication.client.ListeningClient;
import ch.maxant.blog.nio.voipapplication.client.SendingClient;
import ch.maxant.blog.nio.voipapplication.common.VoipProtocol;
import ch.maxant.blog.nio.voipapplication.server.handlers.VoipCallDataHandler;
import ch.maxant.blog.nio.voipapplication.server.handlers.VoipEndCallHandler;
import ch.maxant.blog.nio.voipapplication.server.handlers.VoipLoginHandler;
import ch.maxant.blog.nio.voipapplication.server.handlers.VoipQuitHandler;
import ch.maxant.blog.nio.voipapplication.server.handlers.VoipStartCallHandler;
import ch.maxant.blog.nio.voipapplication.server.handlers.VoipTimeHandler;

public class VoipServerRunner {

	/** 
	 * creates a non blocking server using our proprietry {@link VoipProtocol}.
	 * run this first, then a {@link ListeningClient} and then finally a 
	 * {@link SendingClient}. no args required.
	 */
	public static void main(String[] args) throws IOException {
		
		IServerProtocol<?> protocol = new VoipServerProtocol();
		
		Set<Class<? extends IHandler<?>>> handlers = new HashSet<Class<? extends IHandler<?>>>();
		handlers.add(VoipLoginHandler.class);
		handlers.add(VoipTimeHandler.class);
		handlers.add(VoipStartCallHandler.class);
		handlers.add(VoipCallDataHandler.class);
		handlers.add(VoipEndCallHandler.class);
		handlers.add(VoipQuitHandler.class);

		Configuration config = new Configuration(30032, protocol, handlers);
		
		ServerFactory.createServer(config).listen();
	}
}
