/*  
 * Copyright (c) 2011 Ant Kutschera
 * 
 * This file is part of Ant Kutschera's blog, 
 * http://blog.maxant.co.uk
 * 
 * This is free software: you can redistribute
 * it and/or modify it under the terms of the
 * Lesser GNU General Public License as published by
 * the Free Software Foundation, either version 3 of
 * the License, or (at your option) any later version.
 * 
 * It is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied
 * warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR
 * PURPOSE.  See the Lesser GNU General Public License for
 * more details. 
 * 
 * You should have received a copy of the
 * Lesser GNU General Public License along with this software.
 * If not, see http://www.gnu.org/licenses/.
 */
package ch.maxant.blog.nio.voipapplication.server.handlers;

import java.io.IOException;
import java.nio.ByteBuffer;

import ch.maxant.blog.nio.framework.Handler;
import ch.maxant.blog.nio.voipapplication.common.Packet;
import ch.maxant.blog.nio.voipapplication.common.VoipProtocol;
import ch.maxant.blog.nio.voipapplication.server.VoipRequest;
import ch.maxant.blog.nio.voipapplication.server.VoipResponse;
import ch.maxant.blog.nio.voipapplication.server.model.Participant;

@Handler(selector=""+VoipProtocol.CALL_DATA)
public class VoipCallDataHandler extends VoipHandler {

	public void service(VoipRequest request, VoipResponse response) throws IOException {
		Participant p = (Participant) request.getKey().attachment();
		if(p.getCall() == null || p.getCall().isFinished()){
			//no one in call - tell them to quit
			p.getChannel().write(ByteBuffer.wrap(new Packet(VoipProtocol.END_CALL).marshal()));
		}else{
			for(Participant cp : p.getCall().getParticipants()){
				if(cp.getChannel() == response.getSocketChannel()){
					continue; //dont need to hear own voice!
				}
				
				byte[] data = request.getPacket().marshal();
				int numWritten = cp.getChannel().write(ByteBuffer.wrap(data));
				if(numWritten != data.length) System.err.println("not finished writing all call data being sent to " + cp.getName());
			}
		}
	}

}
