/*  
 * Copyright (c) 2011 Ant Kutschera
 * 
 * This file is part of Ant Kutschera's blog, 
 * http://blog.maxant.co.uk
 * 
 * This is free software: you can redistribute
 * it and/or modify it under the terms of the
 * Lesser GNU General Public License as published by
 * the Free Software Foundation, either version 3 of
 * the License, or (at your option) any later version.
 * 
 * It is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied
 * warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR
 * PURPOSE.  See the Lesser GNU General Public License for
 * more details. 
 * 
 * You should have received a copy of the
 * Lesser GNU General Public License along with this software.
 * If not, see http://www.gnu.org/licenses/.
 */
package ch.maxant.blog.nio.voipapplication.server.handlers;

import java.io.IOException;
import java.nio.ByteBuffer;
import java.nio.channels.ClosedChannelException;

import ch.maxant.blog.nio.framework.Handler;
import ch.maxant.blog.nio.voipapplication.common.Packet;
import ch.maxant.blog.nio.voipapplication.common.VoipProtocol;
import ch.maxant.blog.nio.voipapplication.server.VoipRequest;
import ch.maxant.blog.nio.voipapplication.server.VoipResponse;
import ch.maxant.blog.nio.voipapplication.server.model.Call;
import ch.maxant.blog.nio.voipapplication.server.model.Participant;

@Handler(selector=""+VoipProtocol.END_CALL)
public class VoipEndCallHandler extends VoipHandler {

	public void service(VoipRequest request, VoipResponse response) throws IOException {
		
		//client is leaving call
		//inform all participants that the call is through
		Participant p = (Participant) request.getKey().attachment();

		Call c = p.getCall();
		if(c != null){
			c.removeParticipant(p);
			if(c.isFinished()){
				
				//inform remaining participant to stop sending data
				for(Participant cp : c.getParticipants()){
					try{
						cp.getChannel().write(ByteBuffer.wrap(new Packet(VoipProtocol.END_CALL).marshal()));
					}catch(ClosedChannelException e){
						//couldnt notify client, coz their socket is closed
						System.err.println("Failed to notify " + cp.getName() + " of end of call: " + e);
					}
				}
				
				getProtocol().getModel().removeCall(c);
			}
		}
	}

}
