/*  
 * Copyright (c) 2011 Ant Kutschera
 * 
 * This file is part of Ant Kutschera's blog, 
 * http://blog.maxant.co.uk
 * 
 * This is free software: you can redistribute
 * it and/or modify it under the terms of the
 * Lesser GNU General Public License as published by
 * the Free Software Foundation, either version 3 of
 * the License, or (at your option) any later version.
 * 
 * It is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied
 * warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR
 * PURPOSE.  See the Lesser GNU General Public License for
 * more details. 
 * 
 * You should have received a copy of the
 * Lesser GNU General Public License along with this software.
 * If not, see http://www.gnu.org/licenses/.
 */
package ch.maxant.blog.nio.voipapplication.server.handlers;

import java.io.IOException;

import ch.maxant.blog.nio.framework.IHandler;
import ch.maxant.blog.nio.framework.IServerProtocol;
import ch.maxant.blog.nio.framework.ServerRequest;
import ch.maxant.blog.nio.framework.ServerResponse;
import ch.maxant.blog.nio.voipapplication.server.VoipRequest;
import ch.maxant.blog.nio.voipapplication.server.VoipResponse;
import ch.maxant.blog.nio.voipapplication.server.VoipServerProtocol;

public abstract class VoipHandler implements IHandler<VoipServerProtocol> {

	protected VoipServerProtocol protocol;

	public abstract void service(VoipRequest request, VoipResponse response) throws IOException;
	
	@Override
	public void service(ServerRequest request, ServerResponse response)
			throws IOException {
		
		//call through to something we know - our voip specific method, with a VoipRequest and VoipResponse
		service(new VoipRequest(request.getData(), request.getKey()), new VoipResponse(response.getSocketChannel()));
	}
	
	@Override
	public void setProtocol(IServerProtocol<?> protocol) {
		//cast, because this method is called from the container when 
		//it uses reflection in instantiate the handler
		this.protocol = (VoipServerProtocol) protocol;
	}

	@Override
	public VoipServerProtocol getProtocol() {
		return protocol;
	}
}
