/*  
 * Copyright (c) 2011 Ant Kutschera
 * 
 * This file is part of Ant Kutschera's blog, 
 * http://blog.maxant.co.uk
 * 
 * This is free software: you can redistribute
 * it and/or modify it under the terms of the
 * Lesser GNU General Public License as published by
 * the Free Software Foundation, either version 3 of
 * the License, or (at your option) any later version.
 * 
 * It is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied
 * warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR
 * PURPOSE.  See the Lesser GNU General Public License for
 * more details. 
 * 
 * You should have received a copy of the
 * Lesser GNU General Public License along with this software.
 * If not, see http://www.gnu.org/licenses/.
 */
package ch.maxant.blog.nio.voipapplication.server.handlers;

import java.io.IOException;
import java.nio.ByteBuffer;

import ch.maxant.blog.nio.framework.Handler;
import ch.maxant.blog.nio.voipapplication.common.Packet;
import ch.maxant.blog.nio.voipapplication.common.VoipProtocol;
import ch.maxant.blog.nio.voipapplication.server.VoipRequest;
import ch.maxant.blog.nio.voipapplication.server.VoipResponse;
import ch.maxant.blog.nio.voipapplication.server.model.Call;
import ch.maxant.blog.nio.voipapplication.server.model.Participant;

@Handler(selector=""+VoipProtocol.START_CALL)
public class VoipStartCallHandler extends VoipHandler {

	public void service(VoipRequest request, VoipResponse response) throws IOException {
		String name = request.getPacket().getPayloadAsString();
		
		Participant caller = (Participant) request.getKey().attachment();
		
		Participant callee = getProtocol().getModel().findParticipant(name);

		Packet answer = null;
		if(callee == null){
			//NOK
			answer = new Packet((name + " not online").getBytes(VoipProtocol.CHARSET), VoipProtocol.CALL_NOK);
			System.out.println("Call failed between " + caller.getName() + " and " + name + ": callee offline");
			response.write(answer);
		}else{
			//setup call and ACK
			Call call = new Call();
			getProtocol().getModel().addCall(call, caller, callee);
			answer = new Packet(VoipProtocol.CALL_OK);
			System.out.println("Call started between " + caller.getName() + " and " + callee.getName());
			response.write(answer);
			
			//inform callee too, that they just got called
			answer = new Packet(caller.getName().getBytes(VoipProtocol.CHARSET), VoipProtocol.START_CALL);
			callee.getChannel().write(ByteBuffer.wrap(answer.marshal()));
		}
	}

}
