/*  
 * Copyright (c) 2011 Ant Kutschera
 * 
 * This file is part of Ant Kutschera's blog, 
 * http://blog.maxant.co.uk
 * 
 * This is free software: you can redistribute
 * it and/or modify it under the terms of the
 * Lesser GNU General Public License as published by
 * the Free Software Foundation, either version 3 of
 * the License, or (at your option) any later version.
 * 
 * It is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied
 * warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR
 * PURPOSE.  See the Lesser GNU General Public License for
 * more details. 
 * 
 * You should have received a copy of the
 * Lesser GNU General Public License along with this software.
 * If not, see http://www.gnu.org/licenses/.
 */
package ch.maxant.blog.nio.voipapplication.server.model;

import java.util.ArrayList;
import java.util.Collections;
import java.util.List;

/** 
 * a call between a caller and one or more other participants,
 * basically a list of {@link Participant}s
 */
public class Call {

	private List<Participant> participants = Collections.synchronizedList(new ArrayList<Participant>());
	
	public void addParticipant(Participant participant) {
		participants.add(participant);
	}

	public void removeParticipant(Participant participant) {
		participants.remove(participant);
	}
	
	/** true, if one or no participants */
	public boolean isFinished(){
		return participants.size() <= 1;
	}

	public List<Participant> getParticipants() {
		return participants;
	}
}
