/*  
 * Copyright (c) 2011 Ant Kutschera
 * 
 * This file is part of Ant Kutschera's blog, 
 * http://blog.maxant.co.uk
 * 
 * This is free software: you can redistribute
 * it and/or modify it under the terms of the
 * Lesser GNU General Public License as published by
 * the Free Software Foundation, either version 3 of
 * the License, or (at your option) any later version.
 * 
 * It is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied
 * warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR
 * PURPOSE.  See the Lesser GNU General Public License for
 * more details. 
 * 
 * You should have received a copy of the
 * Lesser GNU General Public License along with this software.
 * If not, see http://www.gnu.org/licenses/.
 */
package ch.maxant.blog.nio.voipapplication.server.model;

import java.nio.channels.SocketChannel;
import java.util.UUID;

/**
 * a participant in a streaming session.  like a call, or streaming video/music.
 */
public class Participant {

	private String name;
	private String sessId = UUID.randomUUID().toString();
	private SocketChannel channel;
	private Call call;

	public Participant(String name, SocketChannel channel) {
		super();
		this.name = name;
		this.channel = channel;
	}
	
	public String getName() {
		return name;
	}
	
	public String getSessId() {
		return sessId;
	}
	
	public SocketChannel getChannel() {
		return channel;
	}
	
	/** notes the call in this participant, and tells the call to add this participant to itself. */
	public void addToCall(Call call){
		this.call = call;
		call.addParticipant(this);
	}
	
	public Call getCall() {
		return call;
	}
	
	/** called by call to remove this participant from that call */
	public void removeFromCall() {
		call = null;
	}
}
