/*  
 * Copyright (c) 2011 Ant Kutschera
 * 
 * This file is part of Ant Kutschera's blog, 
 * http://blog.maxant.co.uk
 * 
 * This is free software: you can redistribute
 * it and/or modify it under the terms of the
 * Lesser GNU General Public License as published by
 * the Free Software Foundation, either version 3 of
 * the License, or (at your option) any later version.
 * 
 * It is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied
 * warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR
 * PURPOSE.  See the Lesser GNU General Public License for
 * more details. 
 * 
 * You should have received a copy of the
 * Lesser GNU General Public License along with this software.
 * If not, see http://www.gnu.org/licenses/.
 */
package ch.maxant.blog.nio.voipapplication.server.model;

import java.util.ArrayList;
import java.util.Collections;
import java.util.HashSet;
import java.util.List;
import java.util.Set;

/**
 * a voice over IP server which knows about logged in {@link Participant}s and {@link Call}s between them.
 */
public class VoipServerModel {

	/** calls currently happening */
	protected static List<Call> calls = Collections.synchronizedList(new ArrayList<Call>());
	
	/** all logged in users.  not necessarily part of any call! */
	protected final static Set<Participant> participants = Collections.synchronizedSet(new HashSet<Participant>());

	public VoipServerModel() {
	}
	
	public void removeCall(Call call) {
		calls.remove(call);
	}

	public void removeParticipant(Participant p) {
		participants.remove(p);
	}

	public void addParticipant(Participant p) {
		participants.add(p);
	}

	/**
	 * @return the participant with that name, or 
	 */
	public Participant findParticipant(String name) {
		for(Participant p : participants){
			if(p.getName().equals(name)){
				return p;
			}
		}
		return null;
	}

	public void addCall(Call call, Participant caller, Participant callee) {
		calls.add(call);
		caller.addToCall(call);
		callee.addToCall(call);
	}

}
