/*  
 * Copyright (c) 2011 Ant Kutschera
 * 
 * This file is part of Ant Kutschera's blog, 
 * http://blog.maxant.co.uk
 * 
 * This is free software: you can redistribute
 * it and/or modify it under the terms of the
 * Lesser GNU General Public License as published by
 * the Free Software Foundation, either version 3 of
 * the License, or (at your option) any later version.
 * 
 * It is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied
 * warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR
 * PURPOSE.  See the Lesser GNU General Public License for
 * more details. 
 * 
 * You should have received a copy of the
 * Lesser GNU General Public License along with this software.
 * If not, see http://www.gnu.org/licenses/.
 */
package ch.maxant.blog.nio.framework;

import java.util.HashSet;
import java.util.Set;

public class Configuration {

	private int port;
	private IServerProtocol<?> protocol;
	private Set<Class<? extends IHandler<?>>> handlers;
	private int maxNumThreadsForAsync = 20;
	
	public Configuration(int port, IServerProtocol<?> protocol, Set<Class<? extends IHandler<?>>> handlers, int maxNumThreadsForAsync){
		this(port, protocol, handlers);
		this.maxNumThreadsForAsync = maxNumThreadsForAsync;
	}

	/**
	 * maxNumThreadsForAsync defaults to 20.
	 * @see #Configuration(int, IServerProtocol, List, int)
	 */
	public Configuration(int port, IServerProtocol<?> protocol, Set<Class<? extends IHandler<?>>> handlers){
		this.port = port;
		this.protocol = protocol;
		this.handlers = handlers;
	}
	
	/** defaults to have no handlers, so the protocol needs to do everything itself */
	public Configuration(int port, IServerProtocol<?> protocol) {
		this(port, protocol, new HashSet<Class<? extends IHandler<?>>>());
	}

	public int getPort() {
		return port;
	}
	
	public IServerProtocol<?> getProtocol() {
		return protocol;
	}
	
	public Set<Class<? extends IHandler<?>>> getHandlers() {
		return handlers;
	}

	public int getMaxNumThreadsForAsync() {
		return maxNumThreadsForAsync ;
	}
	
}
