/*  
 * Copyright (c) 2011 Ant Kutschera
 * 
 * This file is part of Ant Kutschera's blog, 
 * http://blog.maxant.co.uk
 * 
 * This is free software: you can redistribute
 * it and/or modify it under the terms of the
 * Lesser GNU General Public License as published by
 * the Free Software Foundation, either version 3 of
 * the License, or (at your option) any later version.
 * 
 * It is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied
 * warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR
 * PURPOSE.  See the Lesser GNU General Public License for
 * more details. 
 * 
 * You should have received a copy of the
 * Lesser GNU General Public License along with this software.
 * If not, see http://www.gnu.org/licenses/.
 */
package ch.maxant.blog.nio.framework;

import java.io.IOException;
import java.nio.channels.SelectionKey;
import java.nio.channels.SocketChannel;

/**
 * basic protocol for the server.
 * @param M model
 */
public interface IServerProtocol<M> {

	/** 
	 * handle a request from a client.
	 */
	void handleRequest(ServerRequest request, ServerResponse response);

	/**
	 * called when the 
	 * @param client the client which you can write to.  see {@link SocketChannel#write(java.nio.ByteBuffer)}
	 * @param key The selection key, used to attaching or reading the attached data object, relevant to this connection.
	 * @throws IOException if anything goes wrong.
	 */
	void closeClient(SocketChannel client, SelectionKey key);

	/**
	 * @return the size of buffer to use.  the protocol determines the maximum size of packet it might send to the server.
	 * i'm unsure what happens if you send more than this size in one call...  guess it gets split up - then your handler needs to
	 * cope with that!
	 */
	int getBufferSize();

	/** used to tell this protocol what the context is */
	Context getContext();
	
	/** get the model */
	M getModel();
}
