/*  
 * Copyright (c) 2011 Ant Kutschera
 * 
 * This file is part of Ant Kutschera's blog, 
 * http://blog.maxant.co.uk
 * 
 * This is free software: you can redistribute
 * it and/or modify it under the terms of the
 * Lesser GNU General Public License as published by
 * the Free Software Foundation, either version 3 of
 * the License, or (at your option) any later version.
 * 
 * It is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied
 * warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR
 * PURPOSE.  See the Lesser GNU General Public License for
 * more details. 
 * 
 * You should have received a copy of the
 * Lesser GNU General Public License along with this software.
 * If not, see http://www.gnu.org/licenses/.
 */
package ch.maxant.blog.nio.framework.internal;

import java.util.Timer;
import java.util.TimerTask;

public class ServerStats {

	protected static long numConns;
	protected static long numRequests;
	protected static long numRequestsOnLastLog;
	protected static long numBytesProcessed;
	protected static long numMsBusy;
	protected static long numMsIdle;
	
	protected static void setupLogger() {
		Timer t = new Timer("logger", true);
		t.scheduleAtFixedRate(new TimerTask() {
			@Override
			public void run() {

				double reqsPerSec = numRequests - numRequestsOnLastLog;
				numRequestsOnLastLog = numRequests;

				System.out.println("until now, received " + numRequests
						+ " requests, in last sec it was " + reqsPerSec
						+ " reqs/sec, total conns: " + numConns + ", totalThroughput: " + numBytesProcessed + " bytes." +
						" idle for " + numMsIdle + " ms and active for " + numMsBusy + " ms - load is " + (100.0 * numMsBusy / (numMsBusy + numMsIdle)) + "%");
			}
		}, 10000L, 10000L);
	}

	protected void closeClient() {
		numConns--;
	}

	protected void incrementRequests() {
		numRequests++;
	}

	protected long recordIdleTime(long lastRecordedTime) {
		long now;
		now = System.currentTimeMillis();
		numMsIdle += now - lastRecordedTime;
		lastRecordedTime = now;
		return lastRecordedTime;
	}

	protected long recordBusyTime(long lastRecordedTime) {
		long now = System.currentTimeMillis();
		numMsBusy += now - lastRecordedTime;
		lastRecordedTime = now;
		return lastRecordedTime;
	}


}
