/*  
 * Copyright (c) 2011 Ant Kutschera
 * 
 * This file is part of Ant Kutschera's blog, 
 * http://blog.maxant.co.uk
 * 
 * This is free software: you can redistribute
 * it and/or modify it under the terms of the
 * Lesser GNU General Public License as published by
 * the Free Software Foundation, either version 3 of
 * the License, or (at your option) any later version.
 * 
 * It is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied
 * warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR
 * PURPOSE.  See the Lesser GNU General Public License for
 * more details. 
 * 
 * You should have received a copy of the
 * Lesser GNU General Public License along with this software.
 * If not, see http://www.gnu.org/licenses/.
 */
package ch.maxant.blog.nio.framework.tcp;

import java.io.IOException;
import java.nio.channels.SelectionKey;
import java.nio.channels.SocketChannel;

import ch.maxant.blog.nio.framework.Context;
import ch.maxant.blog.nio.framework.IHandler;
import ch.maxant.blog.nio.framework.IServerProtocol;

/**
 * example protocol.  clients of the tcp server need to implement this to do something useful.
 */
public abstract class TCPProtocol implements IServerProtocol<Object> {

	private Context context;

	/** {@inherit} */
	public void closeClient(SocketChannel client, SelectionKey key) {
		key.cancel();
		try {
			client.close();
		} catch (IOException e) {
			//should never happen
			System.err.println("Failed to close socketChannel");
			e.printStackTrace();
		}
	}

	/** default returns a 256KB buffer size */
	@Override
	public int getBufferSize() {
		return 256*1024;
	}
	
	public Context getContext() {
		return context;
	}
	
	/** 
	 * called by the server to set the context into the protocol, so that when the {@link IServerProtocol}
	 * or {@link IHandler} needs 
	 */
	@SuppressWarnings("unused")
	private void setContext(Context context) {
		this.context = context;
	}

	/** default returns null */
	@Override
	public Object getModel() {
		return null;
	}
}
